Config

Struct Config 

pub struct Config {
    pub file: PathBuf,
    pub path: PathBuf,
}

Fields

file: PathBuf

Filename of the current configuration file (default config.toml)

path: PathBuf

Directory that contains the configuration files

Implementations

Source

impl Config

pub fn new(dir: ConfigDirectory) -> Result<Self, ConfigError>

pub fn set_file(&mut self, file: impl Into<PathBuf>) -> &mut Self

Changes the current configuration file

pub fn with_file(self, file: impl Into<PathBuf>) -> Self

Builder pattern to set the current configuration file

pub fn read<T: DeserializeOwned>(&self) -> Result<T, ConfigError>

Reads and deserializes the configuration file into type T

pub fn read_or_default<T: Serialize + DeserializeOwned + Default>( &self, ) -> Result<T, ConfigError>

Reads and deserializes the configuration file into type T. If missing config is written and returns T::default()

pub fn write<T: Serialize>(&self, data: &T) -> Result<(), ConfigError>

Serializes and writes data T to disk as pretty TOML file.

pub fn load_shared<T: Serialize + DeserializeOwned>( self, ) -> Result<SharedConfig<T>, ConfigError>

Loads the config and stores it in a thread safe SharedConfig

pub fn load_shared_or_default<T: Serialize + DeserializeOwned + Default>( self, ) -> Result<SharedConfig<T>, ConfigError>

Loads the config, writes and returns T::default() if missing, and stores it in a thread safe SharedConfig